@@ -1,28 +1,32 @@
-#!/usr/bin/env python
 """
 check links in Markdown files (as used for Static site generation)
-I noted linkchecker program doesn't catch GitHub 404 for example.
 
 linkcheckMarkdown ~/myHugosite/content/posts github.com
 
 linkcheckMarkdown ~/myJekyllsite/_posts
 """
+
 import argparse
 import logging
+import time
 
-from linkcheckmd import run_check
-
-"""
-http://www.useragentstring.com
-"""
-UA = "Mozilla/5.0 (Windows NT 6.1; WOW64; rv:64.0) Gecko/20100101 Firefox/64.0"
+from . import check_remotes, check_local
 
 
-def linkcheck():
-    p = argparse.ArgumentParser()
+def main():
+    # http://www.useragentstring.com
+    user_agent = "Mozilla/5.0 (Windows NT 6.1; WOW64; rv:64.0) Gecko/20100101 Firefox/64.0"
+
+    p = argparse.ArgumentParser(description="check links in markdown sites")
     p.add_argument("path", help="path to Markdown files")
-    p.add_argument("domain", help="check only links to this domain (say github.com without https etc.)", nargs="?")
-    p.add_argument("-a", "--useragent", help="user agent to use instead of default", default=UA)
+    p.add_argument(
+        "domain",
+        help="check only links to this domain (say github.com without https etc.)",
+        nargs="?",
+    )
+    p.add_argument(
+        "-a", "--useragent", help="user agent to use instead of default", default=user_agent
+    )
     p.add_argument("-ext", help="file extension to scan", default=".md")
     p.add_argument(
         "-m",
@@ -33,6 +37,7 @@ def linkcheck():
     )
     p.add_argument("-v", "--verbose", action="store_true")
     p.add_argument("--mode", choices=["sync", "coro"], default="coro")
+    p.add_argument("-local", help="only check local files", action="store_true")
     P = p.parse_args()
 
     if P.verbose:
@@ -40,8 +45,14 @@ def linkcheck():
 
     hdr = {"User-Agent": P.useragent}
 
-    run_check(P.path, P.domain, ext=P.ext, mode=P.mode, hdr=hdr, method=P.method)
+    for bad in check_local(P.path, ext=P.ext):
+        print(bad)
+
+    if not P.local:
+        tic = time.monotonic()
+        check_remotes(P.path, P.domain, ext=P.ext, mode=P.mode, hdr=hdr, method=P.method)
+        print(time.monotonic() - tic, " seconds to check remote links in mode:", P.mode)
 
 
 if __name__ == "__main__":
-    linkcheck()
+    main()
